Date

Struct Date 

pub struct Date { /* private fields */ }
A calendar date.

Implementations

Source

impl Date

pub fn calendar(&self) -> Calendar

Returns the calendar system of this date.

pub fn year(&self) -> i64

Returns the year.

pub fn month(&self) -> u8

Returns the month (1–12).

pub fn day(&self) -> u8

Returns the day of the month (1–31).

pub fn new(year: i64, month: u8, day: u8) -> Result<Date, DateError>

Construct a new Date from a year, month and day. The Calendar is inferred from the input fields.

Errors
pub const fn new_unchecked(year: i64, month: u8, day: u8) -> Date

Constructs a new Date without validation. The Calendar is inferred.

pub fn from_iso(iso: &str) -> Result<Date, DateError>

Constructs a new Date from an ISO 8601 string.

Errors
pub fn from_days_since_j2000(days: i64) -> Date

Constructs a new Date from a signed number of days since J2000. The Calendar is inferred.

pub fn from_seconds_since_j2000(seconds: i64) -> Date

Constructs a new Date from a signed number of seconds since J2000. The Calendar is inferred.

pub fn from_day_of_year(year: i64, day_of_year: u16) -> Result<Date, DateError>

Constructs a new Date from a year and a day number within that year. The Calendar is inferred.

Errors
pub const fn j2000_day_number(&self) -> i64

Returns the day number of self relative to J2000.

pub const fn to_delta(&self) -> TimeDelta

Converts this date to a TimeDelta relative to J2000.