Time

Struct Time 

pub struct Time<T: TimeScale> { /* private fields */ }
An instant in time in a given TimeScale, relative to J2000.

Time supports femtosecond precision, but be aware that many algorithms operating on Times are not accurate to this level of precision.

Implementations

Source

impl<T: TimeScale> Time<T>

pub const fn new(scale: T, seconds: i64, subsecond: Subsecond) -> Self

Instantiates a Time in the given TimeScale from the count of seconds since J2000, subdivided into integral seconds and Subsecond.

pub fn from_date_and_time( scale: T, date: Date, time: TimeOfDay, ) -> Result<Self, TimeError>

Instantiates a Time in the given TimeScale from a Date and a TimeOfDay.

Errors
  • Returns TimeError::LeapSecondsOutsideUtc if time is a leap second, since leap seconds cannot be unambiguously represented by a continuous time format.
pub fn from_iso(scale: T, iso: &str) -> Result<Self, TimeError>

Instantiates a Time in the given TimeScale from an ISO 8601 string.

Errors
  • Returns TimeError::InvalidIsoString if iso is not a valid ISO 8601 timestamp.
pub const fn from_delta(scale: T, delta: TimeDelta) -> Self

Instantiates a Time in the given TimeScale and a TimeDelta relative to J2000.

pub const fn from_epoch(scale: T, epoch: Epoch) -> Self

Returns the Time at epoch in the given TimeScale.

Since Time is defined relative to J2000, this is equivalent to the delta between J2000 and epoch.

pub fn from_julian_date(scale: T, julian_date: Days, epoch: Epoch) -> Self

Given a Julian date, instantiates a Time in the specified TimeScale, relative to epoch.

pub fn from_two_part_julian_date(scale: T, jd1: Days, jd2: Days) -> Self

Instantiates a Time from a two-part Julian date jd1 + jd2 in days.

pub fn builder_with_scale(scale: T) -> TimeBuilder<T>

Returns a TimeBuilder for constructing a new Time in the given TimeScale.

pub fn scale(&self) -> T
where T: Copy,

Returns the timescale

pub fn with_scale<S: TimeScale>(&self, scale: S) -> Time<S>

Returns a new Time with the delta of self but time scale scale.

Note that the underlying delta is simply copied – no time scale transformation takes place.

pub fn try_to_scale<S, P>( &self, scale: S, provider: &P, ) -> Result<Time<S>, P::Error>
where T: Copy, S: TimeScale + Copy, P: TryOffset<T, S> + ?Sized,

Converts this time to scale using the given offset provider.

pub fn to_scale<S>(&self, scale: S) -> Time<S>

Converts this time to scale using the default offset provider.

pub fn with_scale_and_delta<S: TimeScale>( &self, scale: S, delta: TimeDelta, ) -> Time<S>

Returns a new Time with the delta of self adjusted by delta, and time scale scale.

Note that no time scale transformation takes place beyond the adjustment specified by delta.

pub fn jd0(scale: T) -> Self

Returns the Julian epoch as a Time in the given TimeScale.

pub fn mjd0(scale: T) -> Self

Returns the modified Julian epoch as a Time in the given TimeScale.

pub fn j1950(scale: T) -> Self

Returns the J1950 epoch as a Time in the given TimeScale.

pub fn j2000(scale: T) -> Self

Returns the J2000 epoch as a Time in the given TimeScale.

pub fn as_seconds_and_subsecond(&self) -> Option<(i64, Subsecond)>

Returns the seconds and subsecond components, or None if the delta is non-finite.

pub fn seconds(&self) -> Option<i64>

Returns the number of whole seconds since J2000.

pub fn subsecond(&self) -> Option<f64>

Returns the fraction of a second from the last whole second as an f64.

Source

impl<T: TimeScale + Into<DynTimeScale>> Time<T>

pub fn into_dyn(self) -> DynTime

Converts this time into a DynTime with a runtime time scale.