pub enum TimeOfDayError {
InvalidHour(u8),
InvalidMinute(u8),
InvalidSecond(u8),
InvalidSecondOfDay(u64),
InvalidSeconds(InvalidSeconds),
InvalidLeapSecond,
InvalidIsoString(String),
}Expand description
Error type returned when attempting to construct a TimeOfDay from invalid components.
Variants
InvalidHour(u8)
Hour is outside the valid range [0, 24).
InvalidMinute(u8)
Minute is outside the valid range [0, 60).
InvalidSecond(u8)
Second is outside the valid range [0, 61).
InvalidSecondOfDay(u64)
Second of day is outside the valid range [0, 86401).
InvalidSeconds(InvalidSeconds)
Floating-point seconds value is out of range.
InvalidLeapSecond
A leap second was specified at a time other than the end of the day.
InvalidIsoString(String)
The input string is not a valid ISO 8601 time.