Utc

Struct Utc 

pub struct Utc { /* private fields */ }
Coordinated Universal Time.

Implementations

Source

impl Utc

pub fn offset_tai(&self, provider: &impl LeapSecondsProvider) -> TimeDelta

Returns the TAI−UTC offset at this UTC instant.

pub fn to_time_with_provider( &self, provider: &impl LeapSecondsProvider, ) -> Time<Tai>

Converts this UTC instant to TAI using the given leap-seconds provider.

pub fn to_time(&self) -> Time<Tai>

Converts this UTC instant to TAI using the built-in leap-seconds table.

pub fn to_dyn_time_with_provider( &self, provider: &impl LeapSecondsProvider, ) -> DynTime

Converts this UTC instant to a DynTime in TAI using the given provider.

pub fn to_dyn_time(&self) -> DynTime

Converts this UTC instant to a DynTime in TAI using the built-in table.

Source

impl Utc

pub fn new( date: Date, time: TimeOfDay, provider: &impl LeapSecondsProvider, ) -> Result<Self, UtcError>

Creates a new Utc instance from the given Date and TimeOfDay, with leap second validation provided by the LeapSecondsProvider.

Errors
pub fn builder() -> UtcBuilder

Returns a new UtcBuilder.

pub fn from_iso_with_provider<T: LeapSecondsProvider>( iso: &str, provider: &T, ) -> Result<Self, UtcError>

Constructs a new Utc instance from the given ISO 8601 string, with leap second validation provided by the LeapSecondsProvider.

Errors
pub fn from_iso(iso: &str) -> Result<Self, UtcError>

Constructs a new Utc instance from the given ISO 8601 string, with leap second validation provided by [BuiltinLeapSeconds].

pub fn from_delta(delta: TimeDelta) -> Result<Self, UtcError>

Constructs a new Utc instance from a TimeDelta relative to J2000.

Note that this constructor is not leap-second aware.