pub struct UtcBuilder { /* private fields */ }Expand description
A builder for constructing Utc instances piecewise.
Implementations
Sourceimpl UtcBuilder
impl UtcBuilder
Sourcepub fn with_ymd(self, year: i64, month: u8, day: u8) -> Self
pub fn with_ymd(self, year: i64, month: u8, day: u8) -> Self
Sets the year, month and day fields of the Utc instance being built.
Sourcepub fn with_hms(self, hour: u8, minute: u8, seconds: f64) -> Self
pub fn with_hms(self, hour: u8, minute: u8, seconds: f64) -> Self
Sets the hour, minute, second and subsecond fields of the Utc instance being built.
Sourcepub fn build_with_provider(
self,
provider: &impl LeapSecondsProvider,
) -> Result<Utc, UtcError>
pub fn build_with_provider( self, provider: &impl LeapSecondsProvider, ) -> Result<Utc, UtcError>
Constructs the Utc instance with leap second validation provided by the given LeapSecondsProvider.