pub struct Date { /* private fields */ }Expand description
A calendar date.
Implementations
Sourceimpl Date
impl Date
Sourcepub fn new(year: i64, month: u8, day: u8) -> Result<Date, DateError>
pub fn new(year: i64, month: u8, day: u8) -> Result<Date, DateError>
Construct a new Date from a year, month and day. The Calendar is inferred from the input fields.
Errors
- DateError::InvalidDate if the input fields do not represent a valid date.
Sourcepub fn from_iso(iso: &str) -> Result<Date, DateError>
pub fn from_iso(iso: &str) -> Result<Date, DateError>
Constructs a new Date from an ISO 8601 string.
Errors
- DateError::InvalidIsoString if the input string does not contain a valid ISO 8601 date.
- DateError::InvalidDate if the date parsed from the ISO 8601 string is invalid.
Sourcepub fn from_days_since_j2000(days: i64) -> Date
pub fn from_days_since_j2000(days: i64) -> Date
Sourcepub fn from_seconds_since_j2000(seconds: i64) -> Date
pub fn from_seconds_since_j2000(seconds: i64) -> Date
Sourcepub fn from_day_of_year(year: i64, day_of_year: u16) -> Result<Date, DateError>
pub fn from_day_of_year(year: i64, day_of_year: u16) -> Result<Date, DateError>
Constructs a new Date from a year and a day number within that year. The Calendar is inferred.
Errors
- DateError::NonLeapYear if the input day number is 366 and the year is not a leap year.
Sourcepub const fn j2000_day_number(&self) -> i64
pub const fn j2000_day_number(&self) -> i64
Returns the day number of self relative to J2000.