pub struct Time<T: TimeScale> { /* private fields */ }Expand description
An instant in time in a given TimeScale, relative to J2000.
Time supports femtosecond precision, but be aware that many algorithms operating on Times
are not accurate to this level of precision.
Implementations
Sourceimpl<T: TimeScale> Time<T>
impl<T: TimeScale> Time<T>
Sourcepub fn from_date_and_time(
scale: T,
date: Date,
time: TimeOfDay,
) -> Result<Self, TimeError>
pub fn from_date_and_time( scale: T, date: Date, time: TimeOfDay, ) -> Result<Self, TimeError>
Sourcepub const fn from_delta(scale: T, delta: TimeDelta) -> Self
pub const fn from_delta(scale: T, delta: TimeDelta) -> Self
Sourcepub const fn from_epoch(scale: T, epoch: Epoch) -> Self
pub const fn from_epoch(scale: T, epoch: Epoch) -> Self
Sourcepub fn from_julian_date(scale: T, julian_date: Days, epoch: Epoch) -> Self
pub fn from_julian_date(scale: T, julian_date: Days, epoch: Epoch) -> Self
Sourcepub fn from_two_part_julian_date(scale: T, jd1: Days, jd2: Days) -> Self
pub fn from_two_part_julian_date(scale: T, jd1: Days, jd2: Days) -> Self
Instantiates a Time from a two-part Julian date jd1 + jd2 in days.
Sourcepub fn builder_with_scale(scale: T) -> TimeBuilder<T>
pub fn builder_with_scale(scale: T) -> TimeBuilder<T>
Returns a TimeBuilder for constructing a new Time in the given TimeScale.
Sourcepub fn with_scale<S: TimeScale>(&self, scale: S) -> Time<S>
pub fn with_scale<S: TimeScale>(&self, scale: S) -> Time<S>
Returns a new Time with the delta of self but time scale scale.
Note that the underlying delta is simply copied – no time scale transformation takes place.
Sourcepub fn try_to_scale<S, P>(
&self,
scale: S,
provider: &P,
) -> Result<Time<S>, P::Error>
pub fn try_to_scale<S, P>( &self, scale: S, provider: &P, ) -> Result<Time<S>, P::Error>
Converts this time to scale using the given offset provider.
Sourcepub fn to_scale<S>(&self, scale: S) -> Time<S>
pub fn to_scale<S>(&self, scale: S) -> Time<S>
Converts this time to scale using the default offset provider.
Sourcepub fn with_scale_and_delta<S: TimeScale>(
&self,
scale: S,
delta: TimeDelta,
) -> Time<S>
pub fn with_scale_and_delta<S: TimeScale>( &self, scale: S, delta: TimeDelta, ) -> Time<S>
Returns a new Time with the delta of self adjusted by delta, and time scale scale.
Note that no time scale transformation takes place beyond the adjustment specified by
delta.
Sourcepub fn as_seconds_and_subsecond(&self) -> Option<(i64, Subsecond)>
pub fn as_seconds_and_subsecond(&self) -> Option<(i64, Subsecond)>
Returns the seconds and subsecond components, or None if the delta is non-finite.