pub struct Utc { /* private fields */ }Expand description
Coordinated Universal Time.
Implementations
Sourceimpl Utc
impl Utc
Sourcepub fn offset_tai(&self, provider: &impl LeapSecondsProvider) -> TimeDelta
pub fn offset_tai(&self, provider: &impl LeapSecondsProvider) -> TimeDelta
Returns the TAI−UTC offset at this UTC instant.
Sourcepub fn to_time_with_provider(
&self,
provider: &impl LeapSecondsProvider,
) -> Time<Tai>
pub fn to_time_with_provider( &self, provider: &impl LeapSecondsProvider, ) -> Time<Tai>
Converts this UTC instant to TAI using the given leap-seconds provider.
Sourcepub fn to_time(&self) -> Time<Tai>
pub fn to_time(&self) -> Time<Tai>
Converts this UTC instant to TAI using the built-in leap-seconds table.
Sourcepub fn to_dyn_time_with_provider(
&self,
provider: &impl LeapSecondsProvider,
) -> DynTime
pub fn to_dyn_time_with_provider( &self, provider: &impl LeapSecondsProvider, ) -> DynTime
Converts this UTC instant to a DynTime in TAI using the given provider.
Sourcepub fn to_dyn_time(&self) -> DynTime
pub fn to_dyn_time(&self) -> DynTime
Converts this UTC instant to a DynTime in TAI using the built-in table.
Sourceimpl Utc
impl Utc
Sourcepub fn new(
date: Date,
time: TimeOfDay,
provider: &impl LeapSecondsProvider,
) -> Result<Self, UtcError>
pub fn new( date: Date, time: TimeOfDay, provider: &impl LeapSecondsProvider, ) -> Result<Self, UtcError>
Creates a new Utc instance from the given Date and TimeOfDay, with leap second validation provided by the LeapSecondsProvider.
Errors
- UtcError::NonLeapSecondDate if
time.secondsis 60 seconds and the date is not a leap second date.
Sourcepub fn builder() -> UtcBuilder
pub fn builder() -> UtcBuilder
Returns a new UtcBuilder.
Sourcepub fn from_iso_with_provider<T: LeapSecondsProvider>(
iso: &str,
provider: &T,
) -> Result<Self, UtcError>
pub fn from_iso_with_provider<T: LeapSecondsProvider>( iso: &str, provider: &T, ) -> Result<Self, UtcError>
Constructs a new Utc instance from the given ISO 8601 string, with leap second validation provided by the LeapSecondsProvider.
Errors
- UtcError::InvalidIsoString if the input string is not a valid ISO 8601 string.
- UtcError::DateError if the date component of the string is invalid.
- UtcError::TimeError if the time component of the string is invalid.
- UtcError::NonLeapSecondDate if the time component is 60 seconds and the date is not a leap second date.